bayespy.nodes.GaussianGammaARD
==============================

.. currentmodule:: bayespy.nodes

.. autoclass:: GaussianGammaARD

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~GaussianGammaARD.__init__
      ~GaussianGammaARD.add_plate_axis
      ~GaussianGammaARD.broadcasting_multiplier
      ~GaussianGammaARD.delete
      ~GaussianGammaARD.get_gradient
      ~GaussianGammaARD.get_mask
      ~GaussianGammaARD.get_moments
      ~GaussianGammaARD.get_parameters
      ~GaussianGammaARD.get_riemannian_gradient
      ~GaussianGammaARD.get_shape
      ~GaussianGammaARD.has_plotter
      ~GaussianGammaARD.initialize_from_parameters
      ~GaussianGammaARD.initialize_from_prior
      ~GaussianGammaARD.initialize_from_random
      ~GaussianGammaARD.initialize_from_value
      ~GaussianGammaARD.load
      ~GaussianGammaARD.logpdf
      ~GaussianGammaARD.lower_bound_contribution
      ~GaussianGammaARD.lowerbound
      ~GaussianGammaARD.move_plates
      ~GaussianGammaARD.observe
      ~GaussianGammaARD.pdf
      ~GaussianGammaARD.plot
      ~GaussianGammaARD.random
      ~GaussianGammaARD.save
      ~GaussianGammaARD.set_parameters
      ~GaussianGammaARD.set_plotter
      ~GaussianGammaARD.show
      ~GaussianGammaARD.unobserve
      ~GaussianGammaARD.update
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~GaussianGammaARD.dims
      ~GaussianGammaARD.plates
      ~GaussianGammaARD.plates_multiplier
   
   